@@ -1,10 +1,10 @@
-'''
+"""
 Littéraux de chaîne de langue FRANCAIS pour l'application PyMandel tkinter
 
 Créé le 22 avr 2020
 
 @author: semuadmin
-'''
+"""
 # pylint: disable=line-too-long
 
 WIKIURL = "https://fr.wikipedia.org/wiki/Ensemble_de_Mandelbrot"
@@ -17,27 +17,31 @@ COLORCETTXT = "Cartes de couleurs HoloViz Colorcet disponibles sous la licence\n
 
 INTROTXT = "Bienvenue à PyMandel! Utilisez la molette de la souris ou un clic gauche pour zoomer, un clic droit pour centrer."
 
-HELPTXT = "Entrez les paramètres manuellement (ou importez-les à partir d'un fichier de métadonnées) et cliquez sur TRACER pour créer une image fractale avec les paramètres spécifiés.\n\n" \
-    +"Utilisez la molette de la souris pour effectuer un zoom avant et arrière à l'emplacement actuel du curseur.\n" \
-    +"Faites un clic gauche, faites glisser et relâchez - zoomez sur une zone rectangulaire dessinée.\n" \
-    +"Clic gauche - zoomer à l'emplacement du curseur de la valeur de l'incrément de zoom.\n" \
-    +"Maj et Clic gauche - zoom arrière.\n" \
-    +"Appuyez sur Gauche \u25C0 ou Droite \u25B6 en mode Julia pour faire pivoter l'ensemble Julia autour de son origine.\n\n" \
-    +"Bouton TRACER - trace l'image en utilisant les paramètres actuels.\n" \
-    +"Bouton Annuler - annule l'opération de tracé en cours.\n" \
-    +"Bouton de réinitialisation - réinitialise les paramètres aux valeurs par défaut.\n" \
-    +"Bouton Enregistrer - enregistre l'image actuellement affichée sous forme de fichier .png avec ses métadonnées associées sous forme de fichier .json.\n\n" \
-    +"Bouton Zoom - crée automatiquement une séquence d'images zoomées.\n" \
-    +"Bouton de rotation - crée automatiquement une séquence d'images Julia en rotation.\n\n" \
-    +"Fichier..Paramètres d'exportation - pour exporter les paramètres actuels (métadonnées).\n" \
-    +"Fichier..Paramètres d'importation - importer les métadonnées précédemment enregistrées.\n" \
-    +"Options..Masquer / Afficher les paramètres - active ou désactive le panneau des paramètres.\n" \
-    +"Options..Masquer / Afficher l'état - active ou désactive la barre d'état.\n" \
-    +"Aide..Comment - afficher cette boîte de dialogue Comment faire.\n" \
-    +"Aide..À propos - afficher la boîte de dialogue À propos."
+HELPTXT = (
+    "Entrez les paramètres manuellement (ou importez-les à partir d'un fichier de métadonnées) et cliquez sur TRACER pour créer une image fractale avec les paramètres spécifiés.\n\n"
+    + "Utilisez la molette de la souris pour effectuer un zoom avant et arrière à l'emplacement actuel du curseur.\n"
+    + "Faites un clic gauche, faites glisser et relâchez - zoomez sur une zone rectangulaire dessinée.\n"
+    + "Clic gauche - zoomer à l'emplacement du curseur de la valeur de l'incrément de zoom.\n"
+    + "Maj et Clic gauche - zoom arrière.\n"
+    + "Appuyez sur Gauche \u25C0 ou Droite \u25B6 en mode Julia pour faire pivoter l'ensemble Julia autour de son origine.\n\n"
+    + "Bouton TRACER - trace l'image en utilisant les paramètres actuels.\n"
+    + "Bouton Annuler - annule l'opération de tracé en cours.\n"
+    + "Bouton de réinitialisation - réinitialise les paramètres aux valeurs par défaut.\n"
+    + "Bouton Enregistrer - enregistre l'image actuellement affichée sous forme de fichier .png avec ses métadonnées associées sous forme de fichier .json.\n\n"
+    + "Bouton Zoom - crée automatiquement une séquence d'images zoomées.\n"
+    + "Bouton de rotation - crée automatiquement une séquence d'images Julia en rotation.\n\n"
+    + "Fichier..Paramètres d'exportation - pour exporter les paramètres actuels (métadonnées).\n"
+    + "Fichier..Paramètres d'importation - importer les métadonnées précédemment enregistrées.\n"
+    + "Options..Masquer / Afficher les paramètres - active ou désactive le panneau des paramètres.\n"
+    + "Options..Masquer / Afficher l'état - active ou désactive la barre d'état.\n"
+    + "Aide..Comment - afficher cette boîte de dialogue Comment faire.\n"
+    + "Aide..À propos - afficher la boîte de dialogue À propos."
+)
 
-ABOUTTXT = "PyMandel est une application GUI open-source gratuite entièrement écrite en Python et tkinter avec des améliorations de performances Numba.\n\n" \
-    +"Les instructions et le code source sont disponibles sur Github au lien ci-dessous."
+ABOUTTXT = (
+    "PyMandel est une application GUI open-source gratuite entièrement écrite en Python et tkinter avec des améliorations de performances Numba.\n\n"
+    + "Les instructions et le code source sont disponibles sur Github au lien ci-dessous."
+)
 
 # Texte du message
 JITTXT = "PREMIÈRE UTILISATION UNIQUEMENT: veuillez attendre la compilation et la mise en cache JIT"
